module Geri
  module PagesHelper

    def title
      @metadata[:title]
    end

    def site_name
      current_site.name
    end

    def current_site
      Geri::Config.sites[request.host] || Geri::Config.sites[:default]
    end

    def link_to_with_active(name, options = {}, html_options = {}, &block)
      html_options[:class] = html_options[:class] ? html_options[:class] + ' active' : 'active' if current_page?(options)
      link_to name, options, html_options, &block
    end

    def geri_sanitize(content)
      ActionController::Base.helpers.sanitize(content, {
        tags:       %w{ p div strong ol ul li em},
        attributes: %w{ href target }
      })
    end

    def meta_tags
      concat(content_tag(:meta, '', name: :copyright,   content: @metadata[:copyright]))          if @metadata[:copyright]
      concat(content_tag(:meta, '', name: :description, content: @metadata[:description]))        if @metadata[:description]
      concat(content_tag(:meta, '', name: :keywords,    content: @metadata[:keywords].join(','))) if @metadata[:keywords]
      concat(content_tag(:meta, '', name: :robots,      content: @metadata[:robots]))             if @metadata[:robots]
    end

    def editable(name, options={}, &block)
      name    = "#{current_page}_#{name}" unless options[:geri]
      content = Content.find_by(name: name) && geri_sanitize(Content.find_by(name: name).body)
      content ||= capture(&block)
      if current_user
        content = capture do
          content_tag(:div, contenteditable: true, id: name, class: 'editable') { content }
        end
        unless @ckeditor_loaded
          content << javascript_tag('window.CKEDITOR_BASEPATH = "assets/ckeditor/"')
          content << javascript_include_tag('ckeditor/ckeditor')
          content << javascript_tag('CKEDITOR.disableAutoInline = true')
          @ckeditor_loaded = true
        end
        unless @editor_loaded
          content << stylesheet_link_tag('geri/admin/editor')
          content << javascript_include_tag('geri/admin/editor')
        end
        content << javascript_tag do
          %Q{
            CKEDITOR.inline('#{name}', {
              on: {
                change: function(event) {
                  GERI_EDITOR.update(event.editor.name)
                 }
              }
            })
          }.html_safe
        end
      end
      content
    end

  end
end
