module Geri

  # Page encapsulates a site page and it's metadata
  class Page

    class PageNotFoundError < ActionController::RoutingError;
    end
    attr_reader :page_index

    META_CAPTURE = /\A---(.*)\n---\B/m

    # Finds a page within the site and returns a new Page instance
    #
    # @param path[string|NilClass] the url path for which to look for the page
    # @return [Page] a page object
    def self.find(path, current_site, lookup_context)
      path = '' unless path
      new(path, current_site, lookup_context)
    end

    # @private
    def initialize(path, current_site, lookup_context)
      @path           = path
      @current_site   = current_site
      @lookup_context = lookup_context
    end

    # Returns the metadata found in the metadata section of the page as a symbolized hash
    #
    # @return [Hash] the page metadata
    def metadata
      if !@metadata && captured_metadata
        @metadata ||= YAML.load(captured_metadata)
        @metadata.symbolize_keys!
      end
      @metadata || {}
    end

    def content
      @content ||= raw.gsub(META_CAPTURE, '')
    end

    def file
      @file ||=
        (@lookup_context.find(@path + '.html.erb') rescue false) ||
         (@lookup_context.find(@path + '/' + 'index.html.erb') rescue false)
      raise PageNotFoundError.new "Page not found '/#{@path}'" unless @file
      @file
    end

    private

    def captured_metadata
      unless @captured_metadata
        capture            = META_CAPTURE.match(raw)
        @captured_metadata = capture ? capture[1] : nil
      end
      @captured_metadata
    end

    def raw
      file.source
    end

    def site_root
      @current_site.root
    end

  end
end